@@ -121,7 +121,10 @@ class Connection:
         url = urlparse(url)
 
         settings = {}
-        kwargs = {"host": url.hostname}
+        kwargs = {}
+
+        if url.hostname is not None:
+            self._host = kwargs["host"] = unquote(url.hostname)
 
         if url.port is not None:
             self._port = kwargs["port"] = url.port
