@@ -17,10 +17,14 @@ from .intcolumn import (
     Int16Column,
     Int32Column,
     Int64Column,
+    Int128Column,
+    Int256Column,
     UInt8Column,
     UInt16Column,
     UInt32Column,
     UInt64Column,
+    UInt128Column,
+    UInt256Column,
 )
 from .intervalcolumn import (
     IntervalDayColumn,
@@ -34,6 +38,7 @@ from .intervalcolumn import (
 from .ipcolumn import IPv4Column, IPv6Column
 from .lowcardinalitycolumn import create_low_cardinality_column
 from .mapcolumn import create_map_column
+from .nestedcolumn import create_nested_column
 from .nothingcolumn import NothingColumn
 from .nullablecolumn import create_nullable_column
 from .nullcolumn import NullColumn
@@ -53,10 +58,14 @@ column_by_type = {
         Int16Column,
         Int32Column,
         Int64Column,
+        Int128Column,
+        Int256Column,
         UInt8Column,
         UInt16Column,
         UInt32Column,
         UInt64Column,
+        UInt128Column,
+        UInt256Column,
         NothingColumn,
         NullColumn,
         UUIDColumn,
@@ -73,6 +82,16 @@ column_by_type = {
 }
 
 
+aliases = [
+    # Begin Geo types
+    ("Point", "Tuple(Float64, Float64)"),
+    ("Ring", "Array(Point)"),
+    ("Polygon", "Array(Ring)"),
+    ("MultiPolygon", "Array(Polygon)")
+    # End Geo types
+]
+
+
 def get_column_by_spec(spec, column_options):
     def create_column_with_options(x):
         return get_column_by_spec(x, column_options)
@@ -90,24 +109,31 @@ def get_column_by_spec(spec, column_options):
         return create_decimal_column(spec, column_options)
 
     elif spec.startswith("Array"):
-        return create_array_column(spec, create_column_with_options)
+        return create_array_column(spec, create_column_with_options, column_options)
 
     elif spec.startswith("Tuple"):
         return create_tuple_column(spec, create_column_with_options, column_options)
 
+    elif spec.startswith("Nested"):
+        return create_nested_column(spec, create_column_with_options, column_options)
+
     elif spec.startswith("Nullable"):
         return create_nullable_column(spec, create_column_with_options)
 
     elif spec.startswith("LowCardinality"):
-        return create_low_cardinality_column(spec, create_column_with_options)
+        return create_low_cardinality_column(spec, create_column_with_options, column_options)
 
     elif spec.startswith("SimpleAggregateFunction"):
         return create_simple_aggregate_function_column(spec, create_column_with_options)
 
     elif spec.startswith("Map"):
-        return create_map_column(spec, create_column_with_options)
+        return create_map_column(spec, create_column_with_options, column_options)
 
     else:
+        for alias, primitive in aliases:
+            if spec.startswith(alias):
+                return create_column_with_options(primitive + spec[len(alias) :])  # noqa: E203
+
         try:
             cls = column_by_type[spec]
             return cls(**column_options)
