@@ -1,7 +1,7 @@
 from uuid import UUID
 
 from ...errors import CannotParseUuidError
-from ..io import MAX_UINT64
+from ..streams.buffered import MAX_UINT64
 from ..utils import compat
 from .base import FormatColumn
 
@@ -13,7 +13,8 @@ class UUIDColumn(FormatColumn):
 
     # UUID is stored by two uint64 numbers.
     async def write_items(
-        self, items,
+        self,
+        items,
     ):
         n_items = len(items)
 
@@ -27,7 +28,8 @@ class UUIDColumn(FormatColumn):
         await self.writer.write_bytes(s.pack(*uint_64_pairs))
 
     async def read_items(
-        self, n_items,
+        self,
+        n_items,
     ):
         # TODO: cythonize
         s = self.make_struct(2 * n_items)
