@@ -156,6 +156,9 @@ class Connection:
             "opentelemetry_traceparent": self.settings.pop("opentelemetry_traceparent", None),
             "opentelemetry_tracestate": self.settings.pop("opentelemetry_tracestate", ""),
             "quota_key": self.settings.pop("quota_key", ""),
+            "input_format_null_as_default": self.settings.pop(
+                "input_format_null_as_default", False
+            ),
         }
         self.last_query: Optional[QueryInfo] = None
         self.available_client_settings = (
@@ -166,6 +169,7 @@ class Connection:
             "opentelemetry_traceparent",
             "opentelemetry_tracestate",
             "quota_key",
+            "input_format_null_as_default",
         )
         self.context.settings = self.settings
         self.context.client_settings = self.client_settings
@@ -391,7 +395,7 @@ class Connection:
 
         elif packet.type == ServerPacket.PROGRESS:
             self.last_query.store_progress(packet.progress)
-            return packet
+            return True
 
         elif packet.type == ServerPacket.END_OF_STREAM:
             return False
@@ -647,10 +651,10 @@ class Connection:
     async def execute_with_progress(
         self,
         query,
-        params=None,
+        args=None,
         with_column_types=False,
         external_tables=None,
-        query_id=None,
+        query_id="",
         settings=None,
         types_check=False,
         columnar=False,
@@ -660,7 +664,7 @@ class Connection:
         See, :ref:`execute-with-progress`.
 
         :param query: query that will be send to server.
-        :param params: substitution parameters for SELECT queries and data for
+        :param args: substitution parameters for SELECT queries and data for
                        INSERT queries. Data for INSERT can be `list`, `tuple`
                        or :data:`~types.GeneratorType`.
                        Defaults to ``None`` (no parameters  or data).
@@ -684,7 +688,7 @@ class Connection:
         async with ExecuteContext(self, query, settings):
             return await self.process_ordinary_query_with_progress(
                 query,
-                params=params,
+                params=args,
                 with_column_types=with_column_types,
                 external_tables=external_tables,
                 query_id=query_id,
@@ -765,6 +769,9 @@ class Connection:
 
     async def send_external_tables(self, tables, types_check=False):
         for table in tables or []:
+            if not table["structure"]:
+                raise ValueError(f'Empty table "{table["name"]}" structure')
+
             block = RowOrientedBlock(table["structure"], table["data"], types_check=types_check)
             await self.send_block(block, table_name=table["name"])
 
@@ -871,9 +878,7 @@ class Connection:
     def iter_receive_result(self, with_column_types=False):
         gen = self.packet_generator()
 
-        for rows in IterQueryResult(gen, with_column_types=with_column_types):
-            for row in rows:
-                yield row
+        return IterQueryResult(gen, with_column_types=with_column_types)
 
     def track_current_database(self, query):
         query = query.strip("; ")
@@ -883,10 +888,10 @@ class Connection:
     async def execute_iter(
         self,
         query,
-        params=None,
+        args=None,
         with_column_types=False,
         external_tables=None,
-        query_id=None,
+        query_id="",
         settings=None,
         types_check=False,
     ):
@@ -896,7 +901,7 @@ class Connection:
         Executes SELECT query with results streaming. See, :ref:`execute-iter`.
 
         :param query: query that will be send to server.
-        :param params: substitution parameters for SELECT queries and data for
+        :param args: substitution parameters for SELECT queries and data for
                        INSERT queries. Data for INSERT can be `list`, `tuple`
                        or :data:`~types.GeneratorType`.
                        Defaults to ``None`` (no parameters  or data).
@@ -915,12 +920,23 @@ class Connection:
         """
 
         async with ExecuteContext(self, query, settings):
+            is_insert = isinstance(args, (list, tuple, GeneratorType))
 
-            return await self.iter_process_ordinary_query(
-                query,
-                params=params,
-                with_column_types=with_column_types,
-                external_tables=external_tables,
-                query_id=query_id,
-                types_check=types_check,
-            )
+            if is_insert:
+                return await self.process_insert_query(
+                    query,
+                    args,
+                    external_tables=external_tables,
+                    query_id=query_id,
+                    types_check=types_check,
+                    columnar=False,
+                )
+            else:
+                return await self.iter_process_ordinary_query(
+                    query,
+                    params=args,
+                    with_column_types=with_column_types,
+                    external_tables=external_tables,
+                    query_id=query_id,
+                    types_check=types_check,
+                )
